| RcppInt64-package | R Documentation |
'Int64' values can be created and accessed via the 'bit64' package and its 'integer64' class which package the 'int64' representation cleverly into a 'double'. The 'nanotime' packages builds on this to support nanosecond-resolution timestamps. This packages helps conversions between 'R' and 'C++' via several helper functions provided via a single header file. A complete example client package is included as an illustration.
Index: This package was not yet installed at build time.
Dirk Eddelbuettel <edd@debian.org>
Dirk Eddelbuettel [aut, cre] (<https://orcid.org/0000-0001-6419-907X>)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.